@@ -124,7 +124,9 @@ case "$cmd" in
                 diff -u3 /dev/null $edit
             else
                 #   regular case: edited file
-                if ! cmp $orig $edit >/dev/null 2>&1; then
+                if cmp $orig $edit >/dev/null 2>&1; then
+                    :
+                else
                     echo "Index: $edit"
                     diff -u3 $orig $edit
                 fi
